<a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png" /></a><br /><span xmlns:dct="http://purl.org/dc/terms/" href="http://purl.org/dc/dcmitype/StillImage" property="dct:title" rel="dct:type">**taurenmd** logo was created </span> by <a xmlns:cc="http://creativecommons.org/ns#" href="https://viviendomochileros.com/sobre-nosotrs-about-us/" property="cc:attributionName" rel="cc:attributionURL">Joao MC Teixeira and Susana Barrera-Vilarmau</a> using [InkScape](https://inkscape.org/) and is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/">Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License</a>.
